**To delete a namespace**

The following ``delete-namespace`` example deletes a namespace. ::

    aws iotthingsgraph delete-namespace

Output::

    {
       "namespaceArn": "arn:aws:iotthingsgraph:us-west-2:123456789012",
       "namespaceName": "us-west-2/123456789012/default"
    }

For more information, see `Lifecycle Management for AWS IoT Things Graph Entities, Flows, Systems, and Deployments <https://docs.aws.amazon.com/thingsgraph/latest/ug/iot-tg-lifecycle.html>`__ in the *AWS IoT Things Graph User Guide*.
